@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Exporter ();
 
-our $VERSION = '1.500013';
+our $VERSION = '1.500014';
 $VERSION =~ tr/_//d;
 
 our @EXPORT_OK;
@@ -159,8 +159,8 @@ sub sample ($@) {
   my $num = shift;
   my @i = (0 .. $#_);
   $num = @_ if $num > @_;
-  my @o = defined $RAND ? (map +(splice @i, $RAND->($#i), 1), 1 .. $num)
-                        : (map +(splice @i,    rand($#i), 1), 1 .. $num);
+  my @o = defined $RAND ? (map +(splice @i, $RAND->(scalar @i), 1), 1 .. $num)
+                        : (map +(splice @i,    rand(scalar @i), 1), 1 .. $num);
   @_[@o];
 }
 
